@@ -42,12 +42,22 @@ def get_lines_from_file(filename):
 
 
 def get_raw_requirements(filename):
-    lines = get_lines_from_file(filename)
-    return [
-        (parse_requirement(line), filename)
-        for line in lines
-        if not line.startswith('-e ')
-    ]
+    ret = []
+    for line in get_lines_from_file(filename):
+        # allow something to editably install itself
+        if line.strip() == '-e .':
+            continue
+        try:
+            ret.append((parse_requirement(line), filename))
+        except pkg_resources.RequirementParseError as e:
+            raise AssertionError(
+                'Requirements must be <<pkg>> or <<pkg>>==<<version>>\n'
+                ' - git / http / etc. urls may be mutable (unpinnable)\n'
+                ' - transitive dependencies from urls are not traceable\n'
+                ' - line of error: {}\n'
+                ' - inner exception: {!r}\n'.format(line.strip(), e),
+            )
+    return ret
 
 
 def to_version(requirement):
@@ -113,8 +123,7 @@ def format_unpinned_requirements(unpinned_requirements):
     )
 
 
-@pytest.fixture(autouse=True, scope='session')
-def check_requirements_is_only_for_applications():
+def _check_requirements_is_only_for_applications_impl():
     if not os.path.exists('requirements.txt'):
         raise AssertionError(
             'check-requirements is designed specifically with applications '
@@ -124,6 +133,12 @@ def check_requirements_is_only_for_applications():
         )
 
 
+@pytest.fixture(autouse=True, scope='session')
+def check_requirements_is_only_for_applications():  # pragma: no cover
+    """separated as fixtures are not callable in pytest 4+"""
+    _check_requirements_is_only_for_applications_impl()
+
+
 def _get_all_raw_requirements(requirements_files=REQUIREMENTS_FILES):
     # for compatibility with repos that haven't started using
     # requirements-dev-minimal.txt, we don't want to force pinning
@@ -137,15 +152,16 @@ def _get_all_raw_requirements(requirements_files=REQUIREMENTS_FILES):
     ):  # pragma: no cover
         return
 
-    return list(itertools.chain.from_iterable([
-        get_raw_requirements(reqfile)
-        for reqfile in requirements_files
-        if os.path.exists(reqfile)
-    ]))
+    return list(
+        itertools.chain.from_iterable([
+            get_raw_requirements(reqfile)
+            for reqfile in requirements_files
+            if os.path.exists(reqfile)
+        ]),
+    )
 
 
-@pytest.fixture(autouse=True, scope='session')
-def check_requirements_integrity():
+def _check_requirements_integrity_impl():
     raw_requirements = _get_all_raw_requirements()
     if not raw_requirements:
         raise AssertionError(
@@ -164,23 +180,33 @@ def check_requirements_integrity():
                     req.key, filename,
                 ),
             )
-        installed_version = to_version(parse_requirement('{}=={}'.format(
-            req.key, installed_things[req.key].version,
-        )))
+        installed_version = to_version(
+            parse_requirement(
+                '{}=={}'.format(req.key, installed_things[req.key].version),
+            ),
+        )
         if installed_version != version:
             incorrect.append((filename, req.key, version, installed_version))
     if incorrect:
         raise AssertionError(
             'Installed requirements do not match requirement files!\n'
-            'Rebuild your virtualenv:\n{}'.format(''.join(
-                ' - ({}) {}=={} (installed) {}=={}\n'.format(
-                    filename, pkg, depped, pkg, installed,
-                )
-                for filename, pkg, depped, installed in incorrect
-            )),
+            'Rebuild your virtualenv:\n{}'.format(
+                ''.join(
+                    ' - ({}) {}=={} (installed) {}=={}\n'.format(
+                        filename, pkg, depped, pkg, installed,
+                    )
+                    for filename, pkg, depped, installed in incorrect
+                ),
+            ),
         )
 
 
+@pytest.fixture(autouse=True, scope='session')
+def check_requirements_integrity():  # pragma: no cover
+    """separated as fixtures are not callable in pytest 4+"""
+    _check_requirements_integrity_impl()
+
+
 def test_no_duplicate_requirements():
     duplicates = []
     for filename in (
@@ -201,9 +227,12 @@ def test_no_duplicate_requirements():
     if duplicates:
         raise AssertionError(
             'Requirements appeared more than once in the same file:\n'
-            '{}'.format(''.join(
-                '- {} ({})\n'.format(*duplicate) for duplicate in duplicates
-            )),
+            '{}'.format(
+                ''.join(
+                    '- {} ({})\n'.format(*duplicate)
+                    for duplicate in duplicates
+                ),
+            ),
         )
 
 
@@ -378,7 +407,8 @@ def test_no_underscores_all_dashes(requirements_files=REQUIREMENTS_FILES):
         if not os.path.exists(requirement_file):
             continue
         for line in get_lines_from_file(requirement_file):
-            if '_' in line:
+            # ignore the markers for underscore check
+            if '_' in line.split(';')[0]:
                 raise AssertionError(
                     'Use dashes for package names {}: {}'.format(
                         requirement_file, line,
